from setuptools import setup

setup(name='distributions2022',
      version='0.1',
      description='Gaussian distributions and Binomial distributions',
      packages=['distributions2022'],
      author='deepa',
      zip_safe=False)
